@@ -23,6 +23,7 @@ setGeneric("getFilterTerms", function(model, ...) standardGeneric("getFilterTerm
 setGeneric("getLinearFilter", function(model, ...) standardGeneric("getLinearFilter"))
 setGeneric("getModels", function(model, ...) standardGeneric("getModels"))
 setGeneric("getModelMatrix", function(model, col,...) standardGeneric("getModelMatrix"))
+setGeneric("getKernelMatrix", function(model, col,...) standardGeneric("getKernelMatrix"))
 setGeneric("getModelMatrixEnv", function(model, ...) standardGeneric("getModelMatrixEnv"))
 setGeneric("iwlsFit", function(model, ...) standardGeneric("iwlsFit"))
 setGeneric("processData", function(model, ...) standardGeneric("processData"))
@@ -41,4 +42,5 @@ setGeneric("simulate", function(model, ...) standardGeneric("simulate"))
 setGeneric("stepInformation", function(model, ...) standardGeneric("stepInformation"))
 setGeneric("processData<-", function(model, value) standardGeneric("processData<-"))
 setGeneric("termPlot", function(model, ...) standardGeneric("termPlot"))
+setGeneric("updateKernelMatrix", function(model, ...) standardGeneric("updateKernelMatrix"))
 setGeneric("updateModelMatrix", function(model, ...) standardGeneric("updateModelMatrix"))
